Produces forecasts of the conditional standard deviation (and of the conditional mean) following package's models. These methods are not being exported and are used internally only.
# S4 method for fEGarch_fit_egarch
fEGarch_predict(object, n.ahead = 10, trunc = NULL, ...)# S4 method for fEGarch_fit_loggarch
fEGarch_predict(object, n.ahead = 10, trunc = NULL, ...)
# S4 method for fEGarch_fit_aparch
fEGarch_predict(object, n.ahead = 10, trunc = NULL, ...)
# S4 method for fEGarch_fit_fiaparch
fEGarch_predict(object, n.ahead = 10, trunc = NULL, ...)
# S4 method for fEGarch_fit_gjrgarch
fEGarch_predict(object, n.ahead = 10, trunc = NULL, ...)
# S4 method for fEGarch_fit_figjrgarch
fEGarch_predict(object, n.ahead = 10, trunc = NULL, ...)
# S4 method for fEGarch_fit_tgarch
fEGarch_predict(object, n.ahead = 10, trunc = NULL, ...)
# S4 method for fEGarch_fit_fitgarch
fEGarch_predict(object, n.ahead = 10, trunc = NULL, ...)
# S4 method for fEGarch_fit_garch
fEGarch_predict(object, n.ahead = 10, trunc = NULL, ...)
# S4 method for fEGarch_fit_figarch
fEGarch_predict(object, n.ahead = 10, trunc = NULL, ...)
# S4 method for fEGarch_fit
predict_internal(object, n.ahead = 10, trunc = NULL, ...)
They return lists with two numeric vectors as elements named
sigt and cmeans.
these methods are not being exported.
these methods are not being exported.
these methods are not being exported.
these methods are not being exported.